@@ -3,7 +3,7 @@ from tmuxp.plugin import TmuxpPlugin
 
 class PluginReattach(TmuxpPlugin):
     def __init__(self):
-        self.message = '[+] This is the Tmuxp Test Plugin'
+        self.message = "[+] This is the Tmuxp Test Plugin"
 
     def reattach(self, session):
-        session.rename_session('plugin_test_r')
+        session.rename_session("plugin_test_r")
