@@ -1,13 +1,12 @@
 from tmuxp import shell
-from tmuxp._compat import string_types
 
 
-def test_detect_best_shell():
+def test_detect_best_shell() -> None:
     result = shell.detect_best_shell()
-    assert isinstance(result, string_types)
+    assert isinstance(result, str)
 
 
-def test_shell_detect():
+def test_shell_detect() -> None:
     assert isinstance(shell.has_bpython(), bool)
     assert isinstance(shell.has_ipython(), bool)
     assert isinstance(shell.has_ptpython(), bool)
