@@ -25,7 +25,7 @@ def test_raise_BeforeLoadScriptError_if_retcode():
         run_before_script(script_file)
 
 
-def test_return_stdout_if_ok(capsys):
+def test_return_stdout_if_ok(capsys: pytest.CaptureFixture[str]):
     script_file = FIXTURE_PATH / "script_complete.sh"
 
     run_before_script(script_file)
@@ -54,9 +54,7 @@ def test_get_session_should_default_to_local_attached_session(server, monkeypatc
     second_session = server.new_session(session_name="mysecondsession")
 
     # Assign an active pane to the session
-    first_pane_on_second_session_id = second_session.list_windows()[0].list_panes()[0][
-        "pane_id"
-    ]
+    first_pane_on_second_session_id = second_session.windows[0].panes[0].pane_id
     monkeypatch.setenv("TMUX_PANE", first_pane_on_second_session_id)
 
     assert get_session(server) == second_session
